@@ -52,6 +52,7 @@
 #include "kleopatra_options.h"
 
 #include <KCrash>
+#include <KIconTheme>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -70,6 +71,8 @@
 #include <iostream>
 #include <memory>
 
+using namespace Qt::StringLiterals;
+
 QElapsedTimer startupTimer;
 
 static bool selfCheck()
@@ -110,31 +113,47 @@ int main(int argc, char **argv)
             qCWarning(KLEOPATRA_LOG) << "Failed to set GNUPGHOME to" << Kleo::gnupgHomeDirectory();
         }
     }
+    // The config files need to be migrated before the application is created. Otherwise, at least
+    // the staterc might already have been created at the new location.
+    Migration::migrateApplicationConfigFiles(QStringLiteral(KLEOPATRA_APPLICATION_NAME));
+    STARTUP_TIMING << "Config files migrated";
 #endif
 
+    // Enforce the Breeze icon theme for all icons (including recoloring);
+    // needs to be done before creating the QApplication
+    KIconTheme::initTheme();
+    STARTUP_TIMING << "Icon theme initialized";
+
     KleopatraApplication app(argc, argv);
     // Set OrganizationDomain early as this is used to generate the service
     // name that will be registered on the bus.
     app.setApplicationName(QStringLiteral(KLEOPATRA_APPLICATION_NAME));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kleopatra"));
 
     STARTUP_TIMING << "Application created";
+
+    // Early parsing of command line to handle --standalone option
+    QCommandLineParser parser;
+    kleopatra_options(&parser);
+    (void)parser.parse(QApplication::arguments()); // ignore errors; they are handled later
+    app.setIsStandalone(parser.isSet(u"standalone"_s));
+
     /* Create the unique service ASAP to prevent double starts if
      * the application is started twice very quickly. */
-    KUniqueService service;
-    QObject::connect(&service, &KUniqueService::activateRequested, &app, &KleopatraApplication::slotActivateRequested);
-    QObject::connect(&app, &KleopatraApplication::setExitValue, &service, [&service](int i) {
-        service.setExitValue(i);
-    });
-    STARTUP_TIMING << "Service created";
+    if (!app.isStandalone()) {
+        auto service = new KUniqueService(&app);
+        QObject::connect(service, &KUniqueService::activateRequested, &app, &KleopatraApplication::slotActivateRequested);
+        QObject::connect(&app, &KleopatraApplication::setExitValue, service, [service](int i) {
+            service->setExitValue(i);
+        });
+        STARTUP_TIMING << "Unique service created";
+    }
 
     QAccessible::installFactory(Kleo::accessibleWidgetFactory);
-    qCDebug(KLEOPATRA_LOG) << "Application created";
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kleopatra"), app.windowIcon()));
 
-    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kleopatra"));
-
     if (gpgmeInitError) {
         // Show a failed initialization of GpgME after creating QApplication and KUniqueService,
         // and after setting the application domain for the localization.
@@ -184,10 +203,7 @@ int main(int argc, char **argv)
     app.init();
     STARTUP_TIMING << "Application initialized";
 
-    QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
-    kleopatra_options(&parser);
-
     parser.process(QApplication::arguments());
     aboutData.processCommandLine(&parser);
     {
@@ -198,59 +214,60 @@ int main(int argc, char **argv)
     Kleo::ChecksumDefinition::setInstallPath(Kleo::gpg4winInstallPath());
     Kleo::ArchiveDefinition::setInstallPath(Kleo::gnupgInstallPath());
 
-#ifndef DISABLE_UISERVER
-    int rc;
     Kleo::UiServer *server = nullptr;
-    try {
-        server = new Kleo::UiServer(parser.value(QStringLiteral("uiserver-socket")));
-        STARTUP_TIMING << "UiServer created";
+#ifndef DISABLE_UISERVER
+    if (!app.isStandalone()) {
+        try {
+            server = new Kleo::UiServer(parser.value(QStringLiteral("uiserver-socket")));
+            STARTUP_TIMING << "UiServer created";
 
-        QObject::connect(server, &Kleo::UiServer::startKeyManagerRequested, &app, &KleopatraApplication::openOrRaiseMainWindow);
+            QObject::connect(server, &Kleo::UiServer::startKeyManagerRequested, &app, &KleopatraApplication::openOrRaiseMainWindow);
 
-        QObject::connect(server, &Kleo::UiServer::startConfigDialogRequested, &app, &KleopatraApplication::openOrRaiseConfigDialog);
+            QObject::connect(server, &Kleo::UiServer::startConfigDialogRequested, &app, &KleopatraApplication::openOrRaiseConfigDialog);
 
 #define REGISTER(Command) server->registerCommandFactory(std::shared_ptr<Kleo::AssuanCommandFactory>(new Kleo::GenericAssuanCommandFactory<Kleo::Command>))
-        REGISTER(CreateChecksumsCommand);
-        REGISTER(DecryptCommand);
-        REGISTER(DecryptFilesCommand);
-        REGISTER(DecryptVerifyFilesCommand);
-        REGISTER(EchoCommand);
-        REGISTER(EncryptCommand);
-        REGISTER(EncryptFilesCommand);
-        REGISTER(EncryptSignFilesCommand);
-        REGISTER(ImportFilesCommand);
-        REGISTER(PrepEncryptCommand);
-        REGISTER(PrepSignCommand);
-        REGISTER(SelectCertificateCommand);
-        REGISTER(SignCommand);
-        REGISTER(SignEncryptFilesCommand);
-        REGISTER(SignFilesCommand);
-        REGISTER(VerifyChecksumsCommand);
-        REGISTER(VerifyCommand);
-        REGISTER(VerifyFilesCommand);
+            REGISTER(CreateChecksumsCommand);
+            REGISTER(DecryptCommand);
+            REGISTER(DecryptFilesCommand);
+            REGISTER(DecryptVerifyFilesCommand);
+            REGISTER(EchoCommand);
+            REGISTER(EncryptCommand);
+            REGISTER(EncryptFilesCommand);
+            REGISTER(EncryptSignFilesCommand);
+            REGISTER(ImportFilesCommand);
+            REGISTER(PrepEncryptCommand);
+            REGISTER(PrepSignCommand);
+            REGISTER(SelectCertificateCommand);
+            REGISTER(SignCommand);
+            REGISTER(SignEncryptFilesCommand);
+            REGISTER(SignFilesCommand);
+            REGISTER(VerifyChecksumsCommand);
+            REGISTER(VerifyCommand);
+            REGISTER(VerifyFilesCommand);
 #undef REGISTER
 
-        server->start();
-        STARTUP_TIMING << "UiServer started";
-    } catch (const std::exception &e) {
-        qCDebug(KLEOPATRA_LOG) << "Failed to start UI Server: " << e.what();
+            server->start();
+            STARTUP_TIMING << "UiServer started";
+        } catch (const std::exception &e) {
+            qCDebug(KLEOPATRA_LOG) << "Failed to start UI Server: " << e.what();
 #ifdef Q_OS_WIN
-        // We should probably change the UIServer to be only run on Windows at all because
-        // only the Windows Explorer Plugin uses it. But the plan of GnuPG devs as of 2022 is to
-        // change the Windows Explorer Plugin to use the command line and then remove the
-        // UiServer for everyone.
-        QMessageBox::information(nullptr,
-                                 i18n("GPG UI Server Error"),
-                                 i18nc("This error message is only shown on Windows when the socket to communicate with "
-                                       "Windows Explorer could not be created. This often times means that the whole installation is "
-                                       "buggy. e.g. GnuPG is not installed at all.",
-                                       "<qt>The Kleopatra Windows Explorer Module could not be initialized.<br/>"
-                                       "The error given was: <b>%1</b><br/>"
-                                       "This likely means that there is a problem with your installation. Try reinstalling or "
-                                       "contact your Administrator for support.<br/>"
-                                       "You can try to continue to use Kleopatra but there might be other problems.</qt>",
-                                       QString::fromUtf8(e.what()).toHtmlEscaped()));
+            // We should probably change the UIServer to be only run on Windows at all because
+            // only the Windows Explorer Plugin uses it. But the plan of GnuPG devs as of 2022 is to
+            // change the Windows Explorer Plugin to use the command line and then remove the
+            // UiServer for everyone.
+            QMessageBox::information(nullptr,
+                                     i18n("GPG UI Server Error"),
+                                     i18nc("This error message is only shown on Windows when the socket to communicate with "
+                                           "Windows Explorer could not be created. This often times means that the whole installation is "
+                                           "buggy. e.g. GnuPG is not installed at all.",
+                                           "<qt>The Kleopatra Windows Explorer Module could not be initialized.<br/>"
+                                           "The error given was: <b>%1</b><br/>"
+                                           "This likely means that there is a problem with your installation. Try reinstalling or "
+                                           "contact your Administrator for support.<br/>"
+                                           "You can try to continue to use Kleopatra but there might be other problems.</qt>",
+                                           QString::fromUtf8(e.what()).toHtmlEscaped()));
 #endif
+        }
     }
 #endif // DISABLE_UISERVER
     const bool daemon = parser.isSet(QStringLiteral("daemon"));
@@ -285,7 +302,7 @@ int main(int argc, char **argv)
     KMessageBox::setDontShowAgainInterface(messageBoxConfigStorage.get());
 #endif
 
-    rc = app.exec();
+    const int rc = app.exec();
 
     app.setIgnoreNewInstance(true);
     QObject::disconnect(server, &Kleo::UiServer::startKeyManagerRequested, &app, &KleopatraApplication::openOrRaiseMainWindow);
