@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    smartcard/readerstatus.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
 
@@ -79,7 +77,7 @@ public:
 public Q_SLOTS:
     void updateStatus();
     void updateCard(const std::string &serialNumber, const std::string &appName);
-    void learnCards(GpgME::Protocol protocol);
+    void learnCard(const std::string &serialNumber, const std::string &appName);
     void startMonitoring();
 
 Q_SIGNALS:
@@ -91,8 +89,8 @@ Q_SIGNALS:
     void updateCardsStarted();
     void updateCardStarted(const std::string &serialNumber, const std::string &appName);
     void updateFinished();
-    void startingLearnCards(GpgME::Protocol protocol);
-    void cardsLearned(GpgME::Protocol protocol);
+    void startingLearnCard(const std::string &serialNumber, const std::string &appName);
+    void cardLearned(const std::string &serialNumber, const std::string &appName);
     void startOfGpgAgentRequested();
 
 private:
@@ -100,8 +98,8 @@ private:
     void onUpdateCardsStarted();
     void onUpdateCardStarted(const std::string &serialNumber, const std::string &appName);
     void onUpdateFinished();
-    void onStartingLearnCards(GpgME::Protocol protocol);
-    void onCardsLearned(GpgME::Protocol protocol);
+    void onStartingLearnCard(const std::string &serialNumber, const std::string &appName);
+    void onCardLearned(const std::string &serialNumber, const std::string &appName);
 
     class Private;
     std::shared_ptr<Private> d;
